@@ -152,106 +152,242 @@ ListHandleStrings get_key_list(Glib::ustring& mime_type)
  * Mutator functions *
  *********************/
 
+#ifdef GLIBMM_EXCEPTIONS_ENABLED
 void set_default_action_type(const Glib::ustring& mime_type, MimeActionType action_type) throw(exception)
+#else
+void set_default_action_type(const Glib::ustring& mime_type, MimeActionType action_type, std::auto_ptr<Gnome::Vfs::exception>& error)
+#endif //GLIBMM_EXCEPTIONS_ENABLED
 {
   GnomeVFSResult result = gnome_vfs_mime_set_default_action_type(mime_type.c_str(), static_cast<GnomeVFSMimeActionType>(action_type));
+  #ifdef GLIBMM_EXCEPTIONS_ENABLED
   handle_result(result);
+  #else
+  handle_result(result, error);
+  #endif //GLIBMM_EXCEPTIONS_ENABLED
 }
 
+#ifdef GLIBMM_EXCEPTIONS_ENABLED
 void set_default_application(const Glib::ustring& mime_type, const Glib::ustring& application_id) throw(exception)
+#else
+void set_default_application(const Glib::ustring& mime_type, const Glib::ustring& application_id, std::auto_ptr<Gnome::Vfs::exception>& error)
+#endif //GLIBMM_EXCEPTIONS_ENABLED
 {
   GnomeVFSResult result = gnome_vfs_mime_set_default_application(mime_type.c_str(), application_id.c_str());
+  #ifdef GLIBMM_EXCEPTIONS_ENABLED
   handle_result(result);
+  #else
+  handle_result(result, error);
+  #endif //GLIBMM_EXCEPTIONS_ENABLED
 }
 
+#ifdef GLIBMM_EXCEPTIONS_ENABLED
 void set_default_component(const Glib::ustring& mime_type, const Glib::ustring& iid) throw(exception)
+#else
+void set_default_component(const Glib::ustring& mime_type, const Glib::ustring& iid, std::auto_ptr<Gnome::Vfs::exception>& error)
+#endif //GLIBMM_EXCEPTIONS_ENABLED
 {
   GnomeVFSResult result = gnome_vfs_mime_set_default_component(mime_type.c_str(), iid.c_str());
+  #ifdef GLIBMM_EXCEPTIONS_ENABLED
   handle_result(result);
+  #else
+  handle_result(result, error);
+  #endif //GLIBMM_EXCEPTIONS_ENABLED
 }
 
+#ifdef GLIBMM_EXCEPTIONS_ENABLED
 void set_icon(const Glib::ustring& mime_type, const Glib::ustring& filename) throw(exception)
+#else
+void set_icon(const Glib::ustring& mime_type, const Glib::ustring& filename, std::auto_ptr<Gnome::Vfs::exception>& error)
+#endif //GLIBMM_EXCEPTIONS_ENABLED
 {
   GnomeVFSResult result = gnome_vfs_mime_set_icon(mime_type.c_str(), filename.c_str());
+  #ifdef GLIBMM_EXCEPTIONS_ENABLED
   handle_result(result);
+  #else
+  handle_result(result, error);
+  #endif //GLIBMM_EXCEPTIONS_ENABLED
 }
 
+#ifdef GLIBMM_EXCEPTIONS_ENABLED
 void set_description(const Glib::ustring& mime_type, const Glib::ustring& description) throw(exception)
+#else
+void set_description(const Glib::ustring& mime_type, const Glib::ustring& description, std::auto_ptr<Gnome::Vfs::exception>& error)
+#endif //GLIBMM_EXCEPTIONS_ENABLED
 {
   GnomeVFSResult result = gnome_vfs_mime_set_description(mime_type.c_str(), description.c_str());
+  #ifdef GLIBMM_EXCEPTIONS_ENABLED
   handle_result(result);
+  #else
+  handle_result(result, error);
+  #endif //GLIBMM_EXCEPTIONS_ENABLED
 }
 
+#ifdef GLIBMM_EXCEPTIONS_ENABLED
 void set_can_be_executable(const Glib::ustring& mime_type, bool new_value) throw(exception)
+#else
+void set_can_be_executable(const Glib::ustring& mime_type, bool new_value, std::auto_ptr<Gnome::Vfs::exception>& error)
+#endif //GLIBMM_EXCEPTIONS_ENABLED
 {
   GnomeVFSResult result = gnome_vfs_mime_set_can_be_executable(mime_type.c_str(), new_value);
+  #ifdef GLIBMM_EXCEPTIONS_ENABLED
   handle_result(result);
+  #else
+  handle_result(result, error);
+  #endif //GLIBMM_EXCEPTIONS_ENABLED
 }
 
+#ifdef GLIBMM_EXCEPTIONS_ENABLED
 void set_short_list_applications(const Glib::ustring& mime_type, ListHandleStrings& application_ids) throw(exception)
+#else
+void set_short_list_applications(const Glib::ustring& mime_type, ListHandleStrings& application_ids, std::auto_ptr<Gnome::Vfs::exception>& error)
+#endif //GLIBMM_EXCEPTIONS_ENABLED
 {
   GnomeVFSResult result = gnome_vfs_mime_set_short_list_applications(mime_type.c_str(), application_ids.data());
+  #ifdef GLIBMM_EXCEPTIONS_ENABLED
   handle_result(result);
+  #else
+  handle_result(result, error);
+  #endif //GLIBMM_EXCEPTIONS_ENABLED
 }
 
+#ifdef GLIBMM_EXCEPTIONS_ENABLED
 void set_short_list_components(const Glib::ustring& mime_type, ListHandleStrings& component_iids) throw(exception)
+#else
+void set_short_list_components(const Glib::ustring& mime_type, ListHandleStrings& component_iids, std::auto_ptr<Gnome::Vfs::exception>& error)
+#endif //GLIBMM_EXCEPTIONS_ENABLED
 {
   GnomeVFSResult result = gnome_vfs_mime_set_short_list_components(mime_type.c_str(), component_iids.data());
+  #ifdef GLIBMM_EXCEPTIONS_ENABLED
   handle_result(result);
+  #else
+  handle_result(result, error);
+  #endif //GLIBMM_EXCEPTIONS_ENABLED
 }
 
+#ifdef GLIBMM_EXCEPTIONS_ENABLED
 void add_application_to_short_list(const Glib::ustring& mime_type, Glib::ustring& application_id) throw(exception)
+#else
+void add_application_to_short_list(const Glib::ustring& mime_type, Glib::ustring& application_id, std::auto_ptr<Gnome::Vfs::exception>& error)
+#endif //GLIBMM_EXCEPTIONS_ENABLED
 {
   GnomeVFSResult result = gnome_vfs_mime_add_application_to_short_list(mime_type.c_str(), application_id.c_str());
+  #ifdef GLIBMM_EXCEPTIONS_ENABLED
   handle_result(result);
+  #else
+  handle_result(result, error);
+  #endif //GLIBMM_EXCEPTIONS_ENABLED
 }
 
+#ifdef GLIBMM_EXCEPTIONS_ENABLED
 void remove_application_from_short_list(const Glib::ustring& mime_type, Glib::ustring& application_id) throw(exception)
+#else
+void remove_application_from_short_list(const Glib::ustring& mime_type, Glib::ustring& application_id, std::auto_ptr<Gnome::Vfs::exception>& error)
+#endif //GLIBMM_EXCEPTIONS_ENABLED
 {
   GnomeVFSResult result = gnome_vfs_mime_remove_application_from_short_list(mime_type.c_str(), application_id.c_str());
+  #ifdef GLIBMM_EXCEPTIONS_ENABLED
   handle_result(result);
+  #else
+  handle_result(result, error);
+  #endif //GLIBMM_EXCEPTIONS_ENABLED
 }
 
+#ifdef GLIBMM_EXCEPTIONS_ENABLED
 void add_component_to_short_list(const Glib::ustring& mime_type, Glib::ustring& component_iid) throw(exception)
+#else
+void add_component_to_short_list(const Glib::ustring& mime_type, Glib::ustring& component_iid, std::auto_ptr<Gnome::Vfs::exception>& error)
+#endif //GLIBMM_EXCEPTIONS_ENABLED
 {
   GnomeVFSResult result = gnome_vfs_mime_add_component_to_short_list(mime_type.c_str(), component_iid.c_str());
+  #ifdef GLIBMM_EXCEPTIONS_ENABLED
   handle_result(result);
+  #else
+  handle_result(result, error);
+  #endif //GLIBMM_EXCEPTIONS_ENABLED
 }
 
+#ifdef GLIBMM_EXCEPTIONS_ENABLED
 void remove_component_from_short_list(const Glib::ustring& mime_type, Glib::ustring& component_iid) throw(exception)
+#else
+void remove_component_from_short_list(const Glib::ustring& mime_type, Glib::ustring& component_iid, std::auto_ptr<Gnome::Vfs::exception>& error)
+#endif //GLIBMM_EXCEPTIONS_ENABLED
 {
   GnomeVFSResult result = gnome_vfs_mime_remove_component_from_short_list(mime_type.c_str(), component_iid.c_str());
+  #ifdef GLIBMM_EXCEPTIONS_ENABLED
   handle_result(result);
+  #else
+  handle_result(result, error);
+  #endif //GLIBMM_EXCEPTIONS_ENABLED
 }
 
+#ifdef GLIBMM_EXCEPTIONS_ENABLED
 void add_extension(const Glib::ustring& mime_type, Glib::ustring& extension) throw(exception)
+#else
+void add_extension(const Glib::ustring& mime_type, Glib::ustring& extension, std::auto_ptr<Gnome::Vfs::exception>& error)
+#endif //GLIBMM_EXCEPTIONS_ENABLED
 {
   GnomeVFSResult result = gnome_vfs_mime_add_extension(mime_type.c_str(), extension.c_str());
+  #ifdef GLIBMM_EXCEPTIONS_ENABLED
   handle_result(result);
+  #else
+  handle_result(result, error);
+  #endif //GLIBMM_EXCEPTIONS_ENABLED
 }
 
+#ifdef GLIBMM_EXCEPTIONS_ENABLED
 void remove_extension(const Glib::ustring& mime_type, Glib::ustring& extension) throw(exception)
+#else
+void remove_extension(const Glib::ustring& mime_type, Glib::ustring& extension, std::auto_ptr<Gnome::Vfs::exception>& error)
+#endif //GLIBMM_EXCEPTIONS_ENABLED
 {
   GnomeVFSResult result = gnome_vfs_mime_remove_extension(mime_type.c_str(), extension.c_str());
+  #ifdef GLIBMM_EXCEPTIONS_ENABLED
   handle_result(result);
+  #else
+  handle_result(result, error);
+  #endif //GLIBMM_EXCEPTIONS_ENABLED
 }
 
+#ifdef GLIBMM_EXCEPTIONS_ENABLED
 void extend_all_applications(const Glib::ustring& mime_type, ListHandleStrings& application_ids) throw(exception)
+#else
+void extend_all_applications(const Glib::ustring& mime_type, ListHandleStrings& application_ids, std::auto_ptr<Gnome::Vfs::exception>& error)
+#endif //GLIBMM_EXCEPTIONS_ENABLED
 {
   GnomeVFSResult result = gnome_vfs_mime_extend_all_applications(mime_type.c_str(), application_ids.data());
+  #ifdef GLIBMM_EXCEPTIONS_ENABLED
   handle_result(result);
+  #else
+  handle_result(result, error);
+  #endif //GLIBMM_EXCEPTIONS_ENABLED
 }
 
+#ifdef GLIBMM_EXCEPTIONS_ENABLED
 void remove_from_all_applications(const Glib::ustring& mime_type, ListHandleStrings& application_ids) throw(exception)
+#else
+void remove_from_all_applications(const Glib::ustring& mime_type, ListHandleStrings& application_ids, std::auto_ptr<Gnome::Vfs::exception>& error)
+#endif //GLIBMM_EXCEPTIONS_ENABLED
 {
   GnomeVFSResult result = gnome_vfs_mime_remove_from_all_applications(mime_type.c_str(), application_ids.data());
+  #ifdef GLIBMM_EXCEPTIONS_ENABLED
   handle_result(result);
+  #else
+  handle_result(result, error);
+  #endif //GLIBMM_EXCEPTIONS_ENABLED
 }
 
+#ifdef GLIBMM_EXCEPTIONS_ENABLED
 void set_extensions_list(const Glib::ustring& mime_type, const Glib::ustring& extensions_list) throw(exception)
+#else
+void set_extensions_list(const Glib::ustring& mime_type, const Glib::ustring& extensions_list, std::auto_ptr<Gnome::Vfs::exception>& error)
+#endif //GLIBMM_EXCEPTIONS_ENABLED
 {
   GnomeVFSResult result = gnome_vfs_mime_set_extensions_list(mime_type.c_str(), extensions_list.c_str());
+  #ifdef GLIBMM_EXCEPTIONS_ENABLED
   handle_result(result);
+  #else
+  handle_result(result, error);
+  #endif //GLIBMM_EXCEPTIONS_ENABLED
 }
 
 void registered_mime_type_delete(const Glib::ustring& mime_type)
@@ -259,16 +395,32 @@ void registered_mime_type_delete(const Glib::ustring& mime_type)
   gnome_vfs_mime_registered_mime_type_delete(mime_type.c_str());
 }
 
+#ifdef GLIBMM_EXCEPTIONS_ENABLED
 void set_registered_type_key(const Glib::ustring& mime_type, const Glib::ustring& key, const Glib::ustring& data) throw(exception)
+#else
+void set_registered_type_key(const Glib::ustring& mime_type, const Glib::ustring& key, const Glib::ustring& data, std::auto_ptr<Gnome::Vfs::exception>& error)
+#endif //GLIBMM_EXCEPTIONS_ENABLED
 {
   GnomeVFSResult result = gnome_vfs_mime_set_registered_type_key(mime_type.c_str(), key.c_str(), data.c_str());
+  #ifdef GLIBMM_EXCEPTIONS_ENABLED
   handle_result(result);
+  #else
+  handle_result(result, error);
+  #endif //GLIBMM_EXCEPTIONS_ENABLED
 }
 
+#ifdef GLIBMM_EXCEPTIONS_ENABLED
 void set_value(const Glib::ustring& mime_type, const Glib::ustring& key, const Glib::ustring& value) throw(exception)
+#else
+void set_value(const Glib::ustring& mime_type, const Glib::ustring& key, const Glib::ustring& value, std::auto_ptr<Gnome::Vfs::exception>& error)
+#endif //GLIBMM_EXCEPTIONS_ENABLED
 {
   GnomeVFSResult result = gnome_vfs_mime_set_value(mime_type.c_str(), key.c_str(), value.c_str());
+  #ifdef GLIBMM_EXCEPTIONS_ENABLED
   handle_result(result);
+  #else
+  handle_result(result, error);
+  #endif //GLIBMM_EXCEPTIONS_ENABLED
 }
 
 void freeze()
